@@ -43,6 +43,83 @@ class CrossValidation(BaseExperiment):
         best_val_score (float): The best validation score.
 
         n_random_search (int): Number of sampling from distribution when performing random search. 
+
+    Args:
+
+        project_name (str): Name of the project. Directory of {path}/{project_name} will be created.
+
+        X (np.ndarray or torch.Tensor or pd.DataFrame): Data for the project. If X_test is not specified, X would be splitted(stratify=y) into train/val data with a given random state.
+
+        y (np.ndarray or torch.Tensor or pd.DataFrame): Labels for the project. If y_test is not specified, y would be splitted(stratify=y) into train/val labels with a given random state.
+
+        X_train (torch.Tensor): Training data.   
+
+        y_train (torch.Tensor): Training labels.
+
+        X_val (np.ndarray or torch.Tensor or pd.DataFrame, optional): Validation data if explicitly exists.   
+
+        y_val (np.ndarray or torch.Tensor or pd.DataFrame, optional): Validation labels if explicitly exists.
+
+        X_test (np.ndarray or torch.Tensor or pd.DataFrame, optional): Test data if explicitly exists.
+        
+        y_test (np.ndarray or torch.Tensor or pd.DataFrame, optional): Test labels if explicitly exists.
+
+        test_size (float): Test(and validation) size when splitting the data.
+            
+        n_classes (int): Number of classes for the classification task. Don't specify this when performing regression tasks.
+
+        path (str): Base path for the project. Default is the current directory.
+
+        stratify (bool): Whether to use label-stratification in splitting data into train/val/test set.
+            Default: ``True``
+        
+        model_type (`LightningModule`, `BaseEstimator): The type of model (class)
+
+        parameters (dict): Dictionary specifying sets of hyperparameters.
+
+        trainer_config (dict): Trainer configurations. 
+            Default: ``None``
+        
+        val_metric (str): The validation metric.
+            Default: ``'val/acc'``
+
+        mode (str): Mode for validation metric. Either "min" or "max". If left as None, mode will automatically be set for 'val/acc', 'val/auc', and 'val/loss'. If the metric is not one of these, error will be raised.
+            Default: ``None``
+
+        cv (int): K in K-fold cross validation.
+            Default: ``5``
+
+        search_type (str): Search type of the cross validation. Should be "random" or "grid".
+            Default: ``'random'``
+
+        n_random_search (int, optional): Number of sampling from distribution when performing random search. If None, will be set to 5.
+            Default: ``None``
+
+        random_number (int): Random number for random number generator.
+            Default: ``2022``
+
+    Example::
+        
+        >>> parameters= { 
+                            "n_layer_1": {
+                            # Choose from pre-defined values
+                            "values": [32, 64, 128, 256, 512]
+                            },
+                            "n_layer_2": {
+                            # Choose from pre-defined values
+                            "values": [32, 64, 128, 256, 512, 1024]
+                            },
+                            "lr": {
+                                # log uniform distribution between exp(min) and exp(max)
+                                "distribution": "log_scale_uniform",
+                                "min": -9.21,   # exp(-9.21) = 1e-4
+                                "max": -4.61    # exp(-4.61) = 1e-2
+                            }
+                        }
+    Returns:
+
+        None
+            
     """
 
     def __init__(
@@ -68,84 +145,6 @@ class CrossValidation(BaseExperiment):
         random_number : int = DEFAULT_RANDOM_SEED_NUMBER
     ):
 
-        """
-
-        Args:
-
-            project_name (str): Name of the project. Directory of {path}/{project_name} will be created.
-
-            X (np.ndarray or torch.Tensor or pd.DataFrame): Data for the project. If X_test is not specified, X would be splitted(stratify=y) into train/val data with a given random state.
-
-            y (np.ndarray or torch.Tensor or pd.DataFrame): Labels for the project. If y_test is not specified, y would be splitted(stratify=y) into train/val labels with a given random state.
-
-            X_train (torch.Tensor): Training data.   
-
-            y_train (torch.Tensor): Training labels.
-
-            X_val (np.ndarray or torch.Tensor or pd.DataFrame, optional): Validation data if explicitly exists.   
-
-            y_val (np.ndarray or torch.Tensor or pd.DataFrame, optional): Validation labels if explicitly exists.
-
-            X_test (np.ndarray or torch.Tensor or pd.DataFrame, optional): Test data if explicitly exists.
-            
-            y_test (np.ndarray or torch.Tensor or pd.DataFrame, optional): Test labels if explicitly exists.
-
-            test_size (float): Test(and validation) size when splitting the data.
-                
-            n_classes (int): Number of classes for the classification task. Don't specify this when performing regression tasks.
-
-            path (str): Base path for the project. Default is the current directory.
-
-            stratify (bool): Whether to use label-stratification in splitting data into train/val/test set.
-                Default: ``True``
-            
-            model_type (`LightningModule`, `BaseEstimator): The type of model (class)
-
-            parameters (dict): Dictionary specifying sets of hyperparameters.
-
-            trainer_config (dict): Trainer configurations. 
-                Default: ``None``
-            
-            val_metric (str): The validation metric.
-                Default: ``'val/acc'``
-
-            mode (str): Mode for validation metric. Either "min" or "max". If left as None, mode will automatically be set for 'val/acc', 'val/auc', and 'val/loss'. If the metric is not one of these, error will be raised.
-                Default: ``None``
-
-            cv (int): K in K-fold cross validation.
-                Default: ``5``
-
-            search_type (str): Search type of the cross validation. Should be "random" or "grid".
-                Default: ``'random'``
-
-            n_random_search (int, optional): Number of sampling from distribution when performing random search. If None, will be set to 5.
-                Default: ``None``
-
-            random_number (int): Random number for random number generator.
-                Default: ``2022``
-
-        Example::
-            
-            >>> parameters= { 
-                                "n_layer_1": {
-                                # Choose from pre-defined values
-                                "values": [32, 64, 128, 256, 512]
-                                },
-                                "n_layer_2": {
-                                # Choose from pre-defined values
-                                "values": [32, 64, 128, 256, 512, 1024]
-                                },
-                                "lr": {
-                                    # log uniform distribution between exp(min) and exp(max)
-                                    "distribution": "log_scale_uniform",
-                                    "min": -9.21,   # exp(-9.21) = 1e-4
-                                    "max": -4.61    # exp(-4.61) = 1e-2
-                                }
-                            }
-        Returns:
-
-            None
-        """
         self.rng = np.random.default_rng(random_number)
         self.seed_num = int(10**6 * self.rng.random(1))
 
@@ -321,11 +320,12 @@ class CrossValidation(BaseExperiment):
         return data_module
 
     def search(self)->Tuple[Union["pl.LightningModule", "BaseEstimator"], Dict]:
-        r"""Performs cross-validation.
+        """Performs cross-validation.
 
         Returns:
 
             tuple: The best model structure and its information.
+            
         """
         self.fit_or_cv = "CV"
         self.update_log_path()
