@@ -67,7 +67,7 @@ class _MLP(nn.Module):
         activation_type : str = "relu", # "relu" or "leaky_relu"
         negative_slope : Optional[float] = None, # negative slope for leaky relu   
         sample_weight : Optional[Union["np.ndarray", "torch.Tensor"]] = None
-    ) -> None:
+    )->None:
 
         super(_MLP, self).__init__()
         layers = []
@@ -162,7 +162,39 @@ class _MLP(nn.Module):
 
 
 class MLP(BaseNet):
+    """Multi-layer perceptron with identical # of hidden units.
 
+    Args:
+
+        dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
+
+        n_classes (int, optional): Number of classes (labels) in the classification task.
+        
+        n_layers (int): Number of layers. If 1, it would be an old-school perceptron i.e., logistic regression.
+            Default: ``2``
+
+        n_hidden_units (int): Number of hidden units for all hidden layers. 
+            Default : ``10`` 
+
+        batch_size (int): Batch size. 
+            Default : ``64``
+
+        optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
+            Default : ``"adam"`` 
+
+        dropout_p (float): Dropout probability 
+            Default : ``0``
+
+        bn (bool): Whether to use batch normalization or not. 
+            Default : ``True``
+
+        weight_decay (float): Coefficient for L2-regularization. 
+            Default : ``0`` 
+
+        lr (float): Learning rate. 
+            Default: ``1e-4``
+
+    """
     def __init__(
         self,
         dims : Union[int, Tuple[int]],
@@ -170,41 +202,7 @@ class MLP(BaseNet):
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None,
         scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **hparams
-    ) -> None:
-        """Multi-layer perceptron with identical # of hidden units.
-
-        Args:
-
-            dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
-
-            n_classes (int, optional): Number of classes (labels) in the classification task.
-            
-            n_layers (int): Number of layers. If 1, it would be an old-school perceptron i.e., logistic regression.
-                Default: ``2``
-
-            n_hidden_units (int): Number of hidden units for all hidden layers. 
-                Default : ``10`` 
-
-            batch_size (int): Batch size. 
-                Default : ``64``
-
-            optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
-                Default : ``"adam"`` 
-
-            dropout_p (float): Dropout probability 
-                Default : ``0``
-
-            bn (bool): Whether to use batch normalization or not. 
-                Default : ``True``
-
-            weight_decay (float): Coefficient for L2-regularization. 
-                Default : ``0`` 
-
-            lr (float): Learning rate. 
-                Default: ``1e-4``
-
-        """
-        
+    )->None:
         entire_keys = [
             'dims', 
             'n_classes', 
@@ -257,7 +255,36 @@ class MLP(BaseNet):
 
 
 class _ContractingMLP(nn.Module):
+    """ContractingMLP
+        
+    Args:
+    
+        dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
 
+        n_classes (int, optional): Number of classes (labels) in the classification task.
+        
+        contraction_ratio (float): The 0<contraction ratio<1 of the model. Number of hidden units contracts with this ratio.
+            Default: ``0.5``
+
+        batch_size (int): Batch size. 
+            Default : ``64``
+
+        optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
+            Default : ``"adam"`` 
+
+        dropout_p (float): Dropout probability 
+            Default : ``0``
+
+        bn (bool): Whether to use batch normalization or not. 
+            Default : ``True``
+
+        weight_decay (float): Coefficient for L2-regularization. 
+            Default : ``0`` 
+
+        lr (float): Learning rate. 
+            Default: ``1e-4``
+                    
+    """
     def __init__(
         self,
         dims : Union[int, Tuple[int]],
@@ -276,36 +303,6 @@ class _ContractingMLP(nn.Module):
         negative_slope : Optional[float] = None,
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None
     )->None:
-        """ContractingMLP
-        
-        Args:
-        
-            dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
-
-            n_classes (int, optional): Number of classes (labels) in the classification task.
-            
-            contraction_ratio (float): The 0<contraction ratio<1 of the model. Number of hidden units contracts with this ratio.
-                Default: ``0.5``
-
-            batch_size (int): Batch size. 
-                Default : ``64``
-
-            optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
-                Default : ``"adam"`` 
-
-            dropout_p (float): Dropout probability 
-                Default : ``0``
-
-            bn (bool): Whether to use batch normalization or not. 
-                Default : ``True``
-
-            weight_decay (float): Coefficient for L2-regularization. 
-                Default : ``0`` 
-
-            lr (float): Learning rate. 
-                Default: ``1e-4``
-                    
-        """
         super(_ContractingMLP, self).__init__()
 
         if not isinstance(dims, int):
@@ -453,14 +450,34 @@ class _ContractingMLP(nn.Module):
         return self.layers(X)
 
 class ContractingMLP(BaseNet):
-    """ContractingMLP with given contraction ratio.
+    """ContractingMLP
+        
+    Args:
     
-    _ContractingMLP and ContractingMLP defines an MLP with number of hidden units decreasing with a factor
-    of contraction_ratio.
-    Therefore, the hyperparameter that is additionally defined in ContractingMLP is contraction_ratio.
+        dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
 
-    _ContractingMLP and ContractingMLP are basically identical in structure. The only difference is that
-    _ContractingMLP is an offspring of nn.Module and ContractingMLP is an offspring of BaseNet.
+        n_classes (int, optional): Number of classes (labels) in the classification task.
+        
+        contraction_ratio (float): The 0<contraction ratio<1 of the model. Number of hidden units contracts with this ratio.
+            Default: ``0.5``
+
+        batch_size (int): Batch size. 
+            Default : ``64``
+
+        optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
+            Default : ``"adam"`` 
+
+        dropout_p (float): Dropout probability 
+            Default : ``0``
+
+        bn (bool): Whether to use batch normalization or not. 
+            Default : ``True``
+
+        weight_decay (float): Coefficient for L2-regularization. 
+            Default : ``0`` 
+
+        lr (float): Learning rate. 
+            Default: ``1e-4``
 
     """
     def __init__(
@@ -471,37 +488,6 @@ class ContractingMLP(BaseNet):
         scheduler_config: Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **hparams : Any
     )->None:
-        """Initialize ContractingMLP
-        
-        Args:
-        
-            dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
-
-            n_classes (int, optional): Number of classes (labels) in the classification task.
-            
-            contraction_ratio (float): The 0<contraction ratio<1 of the model. Number of hidden units contracts with this ratio.
-                Default: ``0.5``
-
-            batch_size (int): Batch size. 
-                Default : ``64``
-
-            optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
-                Default : ``"adam"`` 
-
-            dropout_p (float): Dropout probability 
-                Default : ``0``
-
-            bn (bool): Whether to use batch normalization or not. 
-                Default : ``True``
-
-            weight_decay (float): Coefficient for L2-regularization. 
-                Default : ``0`` 
-
-            lr (float): Learning rate. 
-                Default: ``1e-4``
-
-        """
-        
         entire_keys = [
             'dims', 
             'n_classes', 
@@ -1058,7 +1044,6 @@ class _UNet(nn.Module):
     """Paper: `U-Net: Convolutional Networks for Biomedical Image Segmentation <https://arxiv.org/abs/1505.04597>`
 
     """
-
     def __init__(
         self,
         n_classes : int, 
@@ -1440,159 +1425,3 @@ class _Discriminator(nn.Module):
 
         return validity
     
-
-"""
-class Generator(GenerativeNet):
-    def __init__(
-        self
-    ):
-        super(Generator, self).__init__()
-    @property
-    def criterion(self, img_batch):
-        
-
-        real = Discriminator(img_batch.view(-1, int(np.prod(self.dims))))
-        fake = Disriminator(Generator())
-        criterion = None
-        return criterion
-    
-    pass
-    def training_step(self, train_batch, batch_idx):
-        x_batch, y_batch = train_batch
-        x_batch = self.reshape_x(x_batch)
-            
-        y_batch = self.sample_weight * y_batch
-
-        Yhat = self.forward(x_batch)
-        if self.n_classes is None:
-            loss = self.criterion(Yhat.squeeze(), y_batch)
-            self.log('train/loss', loss)
-            return {'loss' : loss}
-        else:    
-            if self.n_classes > 2:
-                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
-            else:
-                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.FloatTensor))
-            self.log('train/loss', loss)
-            self.log('train/acc', acc)
-            self.log('train/auc', auc)
-            return {'loss' : loss, 'acc' : acc, 'auc' : auc}
-
-        
-    def validation_step(self, val_batch, batch_idx):
-        x_batch, y_batch = val_batch
-        x_batch = self.reshape_x(x_batch)
-        Yhat = self.forward(x_batch)
-        if self.n_classes is None:
-            loss = self.criterion(Yhat.squeeze(), y_batch)
-            self.log('val/loss', loss)
-            return {'loss' : loss}
-        else:    
-            if self.n_classes > 2:
-                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
-            else:
-                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.FloatTensor))
-
-            self.log('val/loss', loss)
-            self.log('val/acc', acc)
-            self.log('val/auc', auc)
-            return {'loss' : loss, 'acc' : acc, 'auc' : auc}
-
-    def predict_step(self, pred_batch, batch_idx, dataloader_idx=0):
-        x_batch, y_batch = pred_batch
-        x_batch = self.reshape_x(x_batch)
-        Yhat = self.forward(x_batch)
-        if self.n_classes is None:
-            loss = self.criterion(Yhat.squeeze(), y_batch)
-            self.log('pred/loss', loss)
-            return {'loss' : loss}
-        else:    
-            if self.n_classes > 2:
-                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
-            else:
-                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.FloatTensor))
-            self.log('pred/loss', loss)
-            self.log('pred/acc', acc)
-            self.log('pred/auc', auc)
-            return {'loss' : loss, 'acc' : acc, 'auc' : auc}
-
-    def test_step(self, test_batch, batch_idx):
-        x_batch, y_batch = test_batch
-        x_batch = self.reshape_x(x_batch)
-        Yhat = self.forward(x_batch)
-        if self.n_classes is None:
-            loss = self.criterion(Yhat.squeeze(), y_batch)
-            self.log('test/loss', loss)
-            return {'loss' : loss}
-        else:    
-            if self.n_classes > 2:
-                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
-            else:
-                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.FloatTensor))
-            self.log('test/loss', loss)
-            self.log('test/acc', acc)
-            self.log('test/auc', auc)
-            return {'loss' : loss, 'acc' : acc, 'auc' : auc}
-"""
-
-"""
-class Discriminator(BaseNet):
-    def __init__(
-        self,
-        dims : Union[int, Tuple[int]],
-        **hparams : Any
-    ) -> None:
-        entire_keys = [
-            'dims', 
-            'hidden_units', 
-            'optimizer_type', 
-            'batch_size',
-            'lr',
-            'sample_weight',
-            'activation_type',
-            'negative_slope'
-            ]
-        default_parameter_dict = {
-            'hidden_units' : [512, 256],
-            'activation_type' : "leaky_relu",
-            'negative_slope' : 0.2
-        }
-        
-        self.dims = dims
-        
-        # set default for model-specific hyperparameters
-        for argument, default in default_parameter_dict.items():
-            if argument not in hparams.keys(): 
-                hparams.update({argument : default})
-        # set default for model-agnostic hyperparameters
-        if 'lr' not in hparams.keys():
-            hparams.update({'lr' : DEFAULT_LR})
-        if 'optimizer_type' not in hparams.keys():
-            hparams.update({'optimizer_type' : DEFAULT_OPTIMIZER_TYPE})
-        if 'batch_size' not in hparams.keys():
-            hparams.update({'batch_size' : DEFAULT_BATCH_SIZE})
-        
-        # save information of **hparams to self.hparams.
-        self.save_hyperparameters(*hparams)
-        
-        super(Discriminator, self).__init__(
-            dims=dims, 
-            **hparams
-        )
-        # sanity check. Check if right arguments are declared.
-        for key in hparams.keys():
-            if key not in entire_keys:
-                raise ValueError(f'Wrong argument {key} is passed to the model.')
-        self.model = _Discriminator(dims=self.dims, **hparams)
-
-    def forward(self, X):
-        return self.model.forward(X)
-        
-"""            
-"""
-
-TODO : Implement GoogleNet
-TODO : Implement ResNet
-TODO : Implement YOLO
-
-"""
\ No newline at end of file
